package org.samcrow.io;

import java.io.File;
import java.text.ParseException;
import java.util.Collection;

import org.samcrow.Link;
import org.samcrow.Node;

/**
 * Base class for writing maps to files and reading them from files.
 * @author Sam Crow
 */
public abstract class IOBase {
	
	protected File file;
	
	/**
	 * Constructor with a given file path
	 * @param inFilename the name or path of the file
	 */
	public IOBase(String inFilename){
		file = new File(inFilename);
	}
	
	/**
	 * Constructor with a given File object
	 * @param inFile the File object
	 */
	public IOBase(File inFile){
		file = inFile;
	}
	
	/**
	 * Writes to the file that this instance uses
	 * @param nodes the nodes to write
	 * @param links the links to write
	 */
	public abstract void write(Collection<Node> nodes, Collection<Link> links);
	
	/**
	 * Read the file; get the nodes and links defined in it.<br />
	 * This method is designed to be relatively robust.
	 * It will attempt to load data for every data entry that is encountered.
	 * It will ignore lines with malformed data.
	 * It will throw an exception only if an IOException is encountered.
	 * When attempting to read an empty file, it will simply return an IOResponse with empty Collections.
	 * @return IOResponse with the information in the file
	 * @throws ParseException if the file is invalid
	 */
	public abstract IOResponse read() throws ParseException;
}
